==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/komprimierung_monat.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP PROCEDURE IF EXISTS komprimierung_monat//
create procedure komprimierung_monat()
  deterministic
  sql security invoker
begin
  declare nflag bool;
  declare lwid, wid, uid, z integer;
  declare mode varchar(12);
  declare lw varchar(50);
  declare unit, outunit varchar(100);
  declare mw varchar(20000);
  declare mdate, mkd, lastdate date;
  declare selcur cursor for
    select lwerteindizes.ID, werteindizes.ID, groupfunctions.code,
      lkdate, date(lastdatum), unitID, einheiten.name,
      type = 'num' OR groupfunctions.code in ('count','differ','firstsize','lastsize')
    from lwerteindizes
    join werteindizes using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
    join letztewerte on letztewerte.ID = werteindizes.ID
    join teststepdetails on teststepdetails.ID = teststepdetailsID
    join einheiten on einheiten.ID = einheitID
    join groupfunctions on groupfunctions.ID = groupfunctionsID
    left join komprimierungids on komprimierungids.lwerteindizesID = lwerteindizes.ID
    where lastdatum - interval 2 month >= lkdate and period = 'Month'
      and (lwerteindizes.single = '1' OR komprimierungids.lwerteindizesID is not NULL)
    group by lwerteindizes.ID
    order by wtab, werteindizes.ID;
  declare continue handler for not found set z = 1;

  set z = 0;
  open selcur;
  fetch selcur into lwid, wid, mode, mdate, mkd, uid, unit, nflag;
  while z != 1 do
    if mdate = '0000-00-00' then
      set mdate = (select min(fdate) from wertedates where werteindizesID = wid);
      set mdate = mdate - interval (dayofmonth(mdate)-1) day;
    else
      set mdate = mdate + interval 1 month;
    end if;
    set lastdate = mkd - interval 1 month;
    while mdate <= lastdate do
      if (select count(getlastwdate(wid, mdate, mdate + interval 1 month))) > 0 then
        if nflag then
          if unit = '[E]' AND mode not in ('count','differ','firstsize','lastsize') then
            if uid is NULL then
              select lu.unitID
                from lwerteindizes as lr
                join lwerteindizes as lu using (serverID, sectionID, teststepID, teststepdetailsID, accessID)
                where lr.ID = lwid and lu.unitID is not NULL limit 1 into uid;
              if uid is NULL then
                select e.ID
                  from einheiten as e, twerte as w
                  where w.werteindizesID = wid
                    and substr(w.wert, instr(w.wert, ' ')+1) = e.name
                  group by e.ID order by count(*) desc, e.sifaktor desc limit 1 into uid;
              end if;
              if uid is not NULL then
                update lwerteindizes set unitID = uid where ID = lwid;
              end if;
            end if;
            if uid is not NULL then
              select name from einheiten where ID = uid into outunit;
              if mode like 'last-first%' OR mode = 'grad' then
                set mw = getewertvbextfilteru(wid,
                  getlastwdate(wid, mdate - interval 1 month, mdate),
                  mdate + interval 1 month - interval 1 second, mode, '00:00:00',
                  '23:59:59', '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              else
                set mw = getewertvbextfilteru(wid, mdate,
                  mdate + interval 1 month - interval 1 second, mode, '00:00:00',
                  '23:59:59', '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              end if;
              if coalesce(mw, '') != '' then
                insert into mwerte (lwerteindizesID, wert, datum) values
                  (lwid, mw, mdate + interval 14 day);
                call lwdates(lwid, mdate + interval 14 day);
              end if;
            end if;
          else
            if mode like 'last-first%' OR mode = 'grad' then
              set lw = getwertvb(wid, getlastwdate(wid, mdate - interval 1 month, mdate),
                                 mdate + interval 1 month - interval 1 second, mode);
            else
              set lw = getwertvb(wid, mdate, mdate + interval 1 month - interval 1 second,
                                 mode);
            end if;
            if coalesce(lw, '') != '' then
              insert into lwerte (lwerteindizesID, wert, datum) values
                (lwid, lw, mdate + interval 14 day);
              call lwdates(lwid, mdate + interval 14 day);
            end if;
          end if;
        else
          if mode like 'last-first%' OR mode = 'grad' then
            set mw = getwertvb(wid, getlastwdate(wid, mdate - interval 1 month, mdate),
                               mdate + interval 1 month - interval 1 second, mode);
          else
            set mw = getwertvb(wid, mdate, mdate + interval 1 month - interval 1 second,
                               mode);
          end if;
          if coalesce(mw, '') != '' then
            insert into mwerte (lwerteindizesID, wert, datum) values
              (lwid, mw, mdate + interval 14 day);
            call lwdates(lwid, mdate + interval 14 day);
          end if;
        end if;
      end if;
      update lwerteindizes set lkdate = mdate where ID = lwid;
      set mdate = mdate + interval 1 month;
    end while;
    set z = 0;
    fetch selcur into lwid, wid, mode, mdate, mkd, uid, unit, nflag;
  end while;
  close selcur;

end//

GRANT EXECUTE on PROCEDURE komprimierung_monat to loggingadmin@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/komprimierung_monat.sql <==
-- komprimierung_monat.sql
--
-- procedure komprimierung_monat()
-- 
-- calculate and insert compressed values for on month
--
-- komprimiert wird bis zum Vortag der letzten Werte, aber mindestens bis zum vorletzten Monat

set @@character_set_client = 'utf8';

delimiter //

DROP PROCEDURE IF EXISTS komprimierung_monat//
create procedure komprimierung_monat()
  deterministic
  sql security invoker
begin
  declare nflag bool;
  declare lwid, wid, uid, z integer;
  declare mode varchar(12);
  declare lw varchar(50);
  declare unit, outunit varchar(100);
  declare mw varchar(20000);
  declare mdate, mkd, lastdate date;
  declare selcur cursor for
    select lwerteindizes.ID, werteindizes.ID, groupfunctions.code,
      lkdate, greatest(least(date(lastdatum), curdate()), curdate() - interval 1 month), unitID, einheiten.name,
      type = 'num' OR groupfunctions.code in ('count','differ','firstsize','lastsize')
    from lwerteindizes
    join werteindizes using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
    join letztewerte on letztewerte.ID = werteindizes.ID
    join teststepdetails on teststepdetails.ID = teststepdetailsID
    join einheiten on einheiten.ID = einheitID
    join groupfunctions on groupfunctions.ID = groupfunctionsID
    left join komprimierungids on komprimierungids.lwerteindizesID = lwerteindizes.ID
    where lastdatum - interval 2 month >= lkdate and period = 'Month'
      and (lwerteindizes.single = '1' OR komprimierungids.lwerteindizesID is not NULL)
    group by lwerteindizes.ID
    order by wtab, werteindizes.ID;
  declare continue handler for not found set z = 1;

  set z = 0;
  open selcur;
  fetch selcur into lwid, wid, mode, mdate, mkd, uid, unit, nflag;
  while z != 1 do
    if mdate = '0000-00-00' then
      set mdate = (select min(fdate) from wertedates where werteindizesID = wid);
      set mdate = mdate - interval (dayofmonth(mdate)-1) day;
    else
      set mdate = mdate + interval 1 month;
    end if;
    set lastdate = mkd - interval 1 month;
    while mdate <= lastdate do
      if (select count(getlastwdate(wid, mdate, mdate + interval 1 month))) > 0 then
        if nflag then
          if unit = '[E]' AND mode not in ('count','differ','firstsize','lastsize') then
            if uid is NULL then
              select lu.unitID into uid
                from lwerteindizes as lr
                join lwerteindizes as lu using (serverID, sectionID, teststepID, teststepdetailsID, accessID)
                where lr.ID = lwid and lu.unitID is not NULL limit 1;
              if uid is NULL then
                select e.ID into uid
                  from einheiten as e, twerte as w
                  where w.werteindizesID = wid
                    and substr(w.wert, instr(w.wert, ' ')+1) = e.name
                  group by e.ID order by count(*) desc, e.sifaktor desc limit 1;
              end if;
              if uid is not NULL then
                update lwerteindizes set unitID = uid where ID = lwid;
              end if;
            end if;
            if uid is not NULL then
              select name into outunit from einheiten where ID = uid;
              if mode like 'last-first%' OR mode = 'grad' then
                set mw = getewertvbextfilteru(wid,
                  getlastwdate(wid, mdate - interval 1 month, mdate),
                  mdate + interval 1 month - interval 1 second, mode, '00:00:00',
                  '23:59:59', '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              else
                set mw = getewertvbextfilteru(wid, mdate,
                  mdate + interval 1 month - interval 1 second, mode, '00:00:00',
                  '23:59:59', '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              end if;
              if coalesce(mw, '') != '' then
                insert into mwerte (lwerteindizesID, wert, datum) values
                  (lwid, mw, mdate + interval 14 day);
                call lwdates(lwid, mdate + interval 14 day);
              end if;
            end if;
          else
            if mode like 'last-first%' OR mode = 'grad' then
              set lw = getwertvb(wid, getlastwdate(wid, mdate - interval 1 month, mdate),
                                 mdate + interval 1 month - interval 1 second, mode);
            else
              set lw = getwertvb(wid, mdate, mdate + interval 1 month - interval 1 second,
                                 mode);
            end if;
            if coalesce(lw, '') != '' then
              insert into lwerte (lwerteindizesID, wert, datum) values
                (lwid, lw, mdate + interval 14 day);
              call lwdates(lwid, mdate + interval 14 day);
            end if;
          end if;
        else
          if mode like 'last-first%' OR mode = 'grad' then
            set mw = getwertvb(wid, getlastwdate(wid, mdate - interval 1 month, mdate),
                               mdate + interval 1 month - interval 1 second, mode);
          else
            set mw = getwertvb(wid, mdate, mdate + interval 1 month - interval 1 second,
                               mode);
          end if;
          if coalesce(mw, '') != '' then
            insert into mwerte (lwerteindizesID, wert, datum) values
              (lwid, mw, mdate + interval 14 day);
            call lwdates(lwid, mdate + interval 14 day);
          end if;
        end if;
      end if;
      update lwerteindizes set lkdate = mdate where ID = lwid;
      set mdate = mdate + interval 1 month;
    end while;
    set z = 0;
    fetch selcur into lwid, wid, mode, mdate, mkd, uid, unit, nflag;
  end while;
  close selcur;

end//

GRANT EXECUTE on PROCEDURE komprimierung_monat to loggingadmin@'localhost'//
